%% include polycode.fmt

\section{Modelling and Scientific Discovery}
\label{section:discovery}

Experimentation with an executable modelling toolkit such as the one
presented in this article can produce new scientific discoveries,
see~\citep{TranconyWidemann2010}.

> module Discovery where
>
> import Logistic
> import CDF            (uniform, kumaraswamy)
> import CDF.Bisection  (rdata)

It is known that the distribution of states of a dynamical system
specified by the logistic map with $r=4$ converges towards the beta
distribution $B\bigl(\tfrac12, \tfrac12\bigr)$ with the cdf
\begin{equation*}
  B(\alpha, \beta)(y) = \int_0^y t^{\alpha-1}(1-t)^{\beta-1} \,\mathrm dt \Bigm/ \int_0^1 t^{\alpha-1}(1-t)^{\beta-1} \,\mathrm dt
\end{equation*}

It is also known \citep{Kumaraswamy1980} that the beta
distribution $B(\alpha, \beta)$ is related to the algebraically far
simpler Kumaraswamy distribution $K(\alpha, \beta)$ with the cdf
\begin{equation*}
  K(\alpha, \beta)(y) = 1 - (1 - y^\alpha)^\beta
\end{equation*}

\begin{theorem*}
Let $U$ be the standard uniform distribution with the cdf\/ $U(y)=y$. If initial
states in a system specified by the logistic map $f_4$ are distributed
according to the uniform distribution $U$, then after two steps they
are distributed according to the Kumaraswamy distribution $K\bigl(\tfrac12,
\tfrac12\bigr)$. In the notation of \citep{Hauhs2010a},
\begin{equation*}
  \widetilde f_4{}^2(U) = K\bigl(\tfrac12, \tfrac12\bigr)
\end{equation*}
or as a Haskell semantic equation:
< predictCdf 4 2 uniform == kumaraswamy 0.5 0.5
\end{theorem*}

\begin{proof}
Reconsider the definition
\begin{equation*}
  \widetilde f_r(F)(y) = F\bigl(\tfrac12 - q_r(y)\bigr) + 1 -
  F\bigl(\tfrac12 + q_r(y)\bigr)
  \qquad
  q_r(y) = \begin{cases}
    \sqrt{\tfrac14 - \tfrac yr} & \text{if } y \leq \tfrac r4
    \\
    0 & \text{if } y \geq \tfrac r4
  \end{cases}
\end{equation*}

\noindent For $r = 4$ we can simplify
\begin{equation*}
  q_4(y) = \sqrt{\tfrac14 - \tfrac y4} = \tfrac12 \sqrt{1-y}
\end{equation*}
and hence
\begin{equation*}
  \widetilde f_4(F)(y) = F\bigl(\tfrac12(1-\sqrt{1-y})\bigr) + 1 -
  F\bigl(\tfrac12(1+\sqrt{1-y})\bigr)
\end{equation*}

\noindent Then after one step we have
\begin{align*}
  \widetilde f_4(U)(y) &= \frac{1-\sqrt{1-y}}2 + 1 - \frac{1+\sqrt{1-y}}2
  %\\ &
  = 1- \sqrt{1-y}
\end{align*}
and after two steps we have
\begin{align*}
  \widetilde f_4{}^2(U)(y) &= \widetilde f_4\bigl(\widetilde f_4(U)\bigr)(y)
  \\
  &= \widetilde f_4(U)\left(\frac{1-\sqrt{1-y}}2\right) + 1 -
  \widetilde f_4(U)\left(\frac{1+\sqrt{1-y}}2\right)
  \\
  &= \left(1 - \sqrt{1 - \frac{1-\sqrt{1-y}}2}\right) + 1 -
  \left(1 - \sqrt{1 - \frac{1+\sqrt{1-y}}2}\right)
  \\
  &= \left(1 - \sqrt{\frac{1+\sqrt{1-y}}2}\right) + 1 -
  \left(1 - \sqrt{\frac{1-\sqrt{1-y}}2}\right)
  \\
  &= 1 - \underbrace{\left(\sqrt{\frac{1+\sqrt{1-y}}2} - \sqrt{\frac{1-\sqrt{1-y}}2}\right)}_s
\end{align*}

\noindent To simplify the rather convoluted term $s$ we consider the square
\begin{align*}
   s^2 &=
   \left(\sqrt{\frac{1+\sqrt{1-y}}2} - \sqrt{\frac{1-\sqrt{1-y}}2}\right)^2
   \\
    &=
   \frac{1+\sqrt{1-y}}2 - 2\sqrt{\frac{1+\sqrt{1-y}}2}\sqrt{\frac{1-\sqrt{1-y}}2} + \frac{1-\sqrt{1-y}}2
   \\
   &= 1 - \sqrt{(1 - \sqrt{1-y})(1+\sqrt{1-y})}
   \\
   &= 1 - \sqrt{1^2 - (1 - y)}
   %\\ &
   = 1 - \sqrt{y}
\end{align*}

\noindent With $s > 0$ we conclude
\begin{equation*}
  s = \sqrt{1 - \sqrt{y}}
\end{equation*}

\noindent Hence
\begin{equation*}
  \widetilde f_4{}^2(U)(y) = 1 - \sqrt{1 - \sqrt{y}} = 1 - (1 - y^{\frac12})^{\frac12} =
  K\bigl(\tfrac12, \tfrac12\bigr)(y)
\end{equation*}
\end{proof}

This fact has been discovered empirically by examining a diagram (see
Fig.\,\ref{fig:cdfs}) produced from datasets created with the Haskell
operation

> makeFigure1 :: IO ()
> makeFigure1 = mapM_ makeFile datasets
>     where  makeFile  (name, cdf)  =  writeFile name $ rdata 1000 cdf
>            datasets               =  map dataset [0..4]
>            dataset   n            =  (  "logistic" ++ show n ++ ".dat",
>                                         predictCdf 4 n uniform)

and plotted using the statistical tool \textsf{R} with a script
% given in Sect.\,\ref{section:plot} in the appendix.
available in the source code package for this article.
The proof shows that it is nontrivial, and it would hardly have
been discovered without the help of the Haskell implementation.

\begin{figure}
\centering
%if extended
\pgfimage[width=0.7\textwidth]{figure1}
%else
\pgfimage[width=0.7\textwidth]{figure1}
%endif
\caption{State cdfs $D_n = \widetilde f_4{}^n(U)$ of an initially uniformly distributed system running the logistic map with $r=4$, after |n <- [0 .. 4]| steps, plotted over the uniform ($U$), Kumaraswamy ($K$) and beta ($B$) distributions, the latter two with parameters $\alpha = \beta = \tfrac12$. $D_0$ coincides with $U$. $D_2$ coincides with $K$. For $n > 3$, $D_n$ converges towards $B$.}
\label{fig:cdfs}
\end{figure}
