doplot <- function(maxn=4, resolution=1000, bw=F, delta=NULL,
                   device=NULL, ...) {
  unicol <- "black"
  betacol <- "black"
  kumacol <- "black"
  if (bw) logcol <- rep(rgb(0.33,0.33,0.33), maxn+1) else logcol <- rainbow(maxn+1)

  unilty <- 5
  kumalty <- 4
  betalty <- 3
  loglty <- rep(1, maxn+1)

  if (bw) logpch <- 0:maxn else logpch <- rep(NA, maxn+1)

  wide <- 5
  if (bw) narrow <- 1 else narrow <- 2

  t <- list()
  for (n in 0:maxn)
    t[[n+1]] <- read.table(paste("logistic", n, ".dat", sep=""),
                           sep="\t")

  if (!is.null(device))
    device(...)
  par(mar=c(4,4,1.5,0)+0.1)
  xs <- seq(0, 1, length=resolution)
  plot(function(x) pbeta(x, 0.5, 0.5), lwd=wide, col=betacol, lty=betalty,
       xlab="y", ylab="P(X < y)", main="Cumulative Distributions")
  lines(c(0,1), c(0,1), lwd=wide, col=unicol, lty=unilty)
  lines(xs, sapply(xs, function(x) 1 - sqrt(1 - sqrt(x))),
        lwd=wide, col=kumacol, lty=kumalty)
  for (n in 0:maxn) {
    u <- t[[n+1]]
    lines(u, col=logcol[n+1], lty=loglty[n+1], lwd=narrow)
    if (!is.null(delta))
      points(thin(u, delta), pch=logpch[n+1], col=logcol[n+1], lwd=narrow)
  }
  legend("topleft", lwd=c(rep(wide, 3), rep(narrow, maxn+1)),
         legend=c("U", "K", "B", sapply(0:maxn, function(n) paste("n =", n))),
         lty=c(unilty, kumalty, betalty, loglty),
         col=c(unicol, kumacol, betacol, logcol),
         pch=c(NA, NA, NA, logpch))
  if (!is.null(device))
    dev.off()
}

thin <- function(x, delta=0.05) {
  n <- nrow(x)
  m <- ncol(x)
  y <- matrix(nrow=n, ncol=m)
  d <- delta
  for (i in 1:n) {
    if (d >= delta) {
      for (j in 1:m) y[i,j] <- x[i,j]
      d <- 0
    }
    if (i < n)
      d <- d + sqrt(sum((x[i+1,] - x[i,])^2))
  }
  na.omit(y)
}

doplot(bw=F, device=pdf, file="figure1.pdf", width=7, height=5)
doplot(bw=F, device=postscript, file="figure1.eps",
       width=7, height=5, paper="special", horizontal=F)

doplot(bw=T, delta=0.05, device=pdf, file="figure1_bw.pdf", width=7, height=5)
doplot(bw=T, delta=0.05, device=postscript, file="figure1_bw.eps",
       width=7, height=5, paper="special", horizontal=F)
